@@ -27,7 +27,7 @@ class Simulation:
 		dirname = os.path.dirname(__file__)
 		self.all_donors = pd.read_csv(os.path.join(dirname, donor_path),parse_dates=['date'],index_col=0)
 		self.all_recipients = pd.read_csv(os.path.join(dirname, recipient_path),parse_dates=['date'],index_col=0)
-		self.distance_mat = pd.read_csv(os.path.join(dirname, distance_matrix_path), index_col=0)
+		self.distance_mat = pd.read_csv(os.path.join(dirname, distance_matrix_path))
 		# Initialize dataframes
 		self.all_granular_decisions = pd.DataFrame(columns=['don_id', 'rec_id', 'ppe','date', 'qty', 'distance', 'holding_time'])
 		self.metrics = None
